==> dbstyleguidechecker-2.0.5.tar.gz: lib/src/reporters/console_code_style_violations_reporter.dart <==
/*
 * BSD 3-Clause License
 *
 * Copyright (c) 2020, Bitsy Darel
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import 'dart:io';

import 'package:dbstyleguidechecker/dbstyleguidechecker.dart';
import 'package:dbstyleguidechecker/src/code_style_violation.dart';
import 'package:io/ansi.dart';

/// Create [CodeStyleViolationsReporter] that report violation to the console.
class ConsoleCodeStyleViolationsReporter extends CodeStyleViolationsReporter {
  /// Create a constant instance of the [ConsoleCodeStyleViolationsReporter].
  const ConsoleCodeStyleViolationsReporter();

  @override
  Future<void> report(List<CodeStyleViolation> violations) async {
    for (final CodeStyleViolation violation in violations) {
      if (violation.severity.level > ViolationSeverity.info.level) {
        stderr.writeln(
          red.wrap(
            '${violation.severity.id}, ${violation.ruleDescription} in file '
            '${violation.file} at line ${violation.line}, line column '
            '${violation.lineColumn}',
          ),
        );
      } else {
        stdout.writeln(
          yellow.wrap(
            '${violation.severity.id}, ${violation.ruleDescription} in file '
            '${violation.file} at line ${violation.line}, line column '
            '${violation.lineColumn}',
          ),
        );
      }
    }
  }
}

==> dbstyleguidechecker-3.0.2.tar.gz: lib/src/reporters/console_code_style_violations_reporter.dart <==
/*
 * BSD 3-Clause License
 *
 * Copyright (c) 2020, Bitsy Darel
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. Neither the name of the copyright holder nor the names of its
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import 'dart:io';

import 'package:dbstyleguidechecker/src/code_style_violation.dart';
import 'package:dbstyleguidechecker/src/reporters/code_style_violations_reporter.dart';
import 'package:io/ansi.dart';

/// Create [CodeStyleViolationsReporter] that report violation to the console.
class ConsoleCodeStyleViolationsReporter extends CodeStyleViolationsReporter {
  /// Create a constant instance of the [ConsoleCodeStyleViolationsReporter].
  const ConsoleCodeStyleViolationsReporter();

  @override
  Future<void> report(List<CodeStyleViolation> violations) async {
    for (final CodeStyleViolation violation in violations) {
      if (violation.severity.level > ViolationSeverity.info.level) {
        stderr.writeln(
          red.wrap(
            '${violation.severity.id}, ${violation.ruleDescription} in file '
            '${violation.file} at line ${violation.line}, line column '
            '${violation.lineColumn}',
          ),
        );
      } else {
        stdout.writeln(
          yellow.wrap(
            '${violation.severity.id}, ${violation.ruleDescription} in file '
            '${violation.file} at line ${violation.line}, line column '
            '${violation.lineColumn}',
          ),
        );
      }
    }
  }
}
